@@ -1,7 +1,7 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: CL-INTERPOL; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/cl-interpol/specials.lisp,v 1.7 2004/04/24 00:19:13 edi Exp $
+;;; $Header: /usr/local/cvsrep/cl-interpol/specials.lisp,v 1.12 2008/07/23 13:58:40 edi Exp $
 
-;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
+;;; Copyright (c) 2003-2008, Dr. Edmund Weitz. All rights reserved.
 
 ;;; Redistribution and use in source and binary forms, with or without
 ;;; modification, are permitted provided that the following conditions
@@ -27,7 +27,7 @@
 ;;; NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 ;;; SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-(in-package #:cl-interpol)
+(in-package :cl-interpol)
 
 (defvar *list-delimiter* #\Space
   "What is inserted between the elements of a list which is
@@ -49,19 +49,9 @@ interpolated by #\@.")
 (defvar *regex-delimiters* '(#\/)
   "Outer delimiters which automatically enable regex mode.")
 
-(defvar *unicode-names*
-  (make-hash-table :test #'equalp :size (min 14000 (+ 50 char-code-limit)))
-  "A hash table which maps Unicode names to characters.")
-
-(defvar *long-unicode-names-p* t
-  "Whether long Unicode names should be tried")
-
-(defvar *short-unicode-names-p* nil
-  "Whether long Unicode names \(like \"Greek:Sigma\") should be tried")
-
-(defvar *unicode-scripts* '("latin")
-  "The Unicode scripts which are to be tried if a name couldn't be
-resolved otherwise.")
+(defvar *unicode-aliases*
+  (make-hash-table :test #'equalp)
+  "A hash table which maps Unicode aliases to their real names.")
 
 (defvar *optional-delimiters-p* nil
   "Whether text following $ or @ should interpolate even without a
